# -*- coding: utf-8 -*-

from odoo import models
from odoo.osv import expression
from odoo.tools import babel_locale_parse



class CalendarAppointmentType(models.Model):
    _inherit = "appointment.type"


    def get_url_by_dept_country(self, departments, country_code=False, lang_code=False):
        """
            Helper to retrieve the URL for the calendar appointment used by our Sales.

            :param list departments: List of departments for which we search the URL (e.g. ['AM', 'PR', 'DS'])
            :param str country_code: The country code for which we want to limit the search
            :param str lang_code: For countries with multiple langs, a language code can be passed to return the correct URL (e.g. Belgium where Dutch and French are spoken)

            :return: The calendar appointment page URL for the customer to schedule a meeting
            :rtype: str
        """
        search_domain = []

        # create the domain to search on departments
        for dpt in departments:
            search_domain = expression.OR([
                search_domain,
                [
                    ('name', 'ilike', '- %s -' % dpt)
                ]
            ])

        # filter by country_code
        if country_code:
            search_domain = expression.AND([
                search_domain,
                [('country_ids.code', '=ilike', country_code)]
            ])

        # search for the appointment types that match our domain
        type_ids = self.search(search_domain)

        # if we match multiple appointment types, we may need to filter out by language
        if len(type_ids) > 1 and lang_code:
            # parse the lang code to find the language
            # i.e. fr_BE => FR
            parsed_language = babel_locale_parse(lang_code)
            lang_search_pattern = '(%s)' % parsed_language.language.upper()
            # search for type that contains in their name the language between parenthesis, i.e. "(FR)"
            type_filtered_lang = type_ids.filtered(lambda x: lang_search_pattern in x.name)
            # if we have found type that match the language then we use it, otherwise use the unfiltered list as fallback
            type_ids = type_filtered_lang or type_ids

        # return the URL
        return type_ids[:1].website_url or self._get_dept_default_url(departments)


    def _get_dept_default_url(self, departments):
        """
            Return the website_url of the default appointment type for the
            first valid departments.
            Valid departments are DS, AM, PR
        """
        default = self.env.ref('openerp_website.default_appointment_ds')
        default_map = {
            'DS': self.env.ref('openerp_website.default_appointment_ds'),  # 124
            'AM': self.env.ref('openerp_website.default_appointment_am'),  # 85
            'PR': self.env.ref('openerp_website.default_appointment_pr'),  # 44
        }
        return next((default_map[d.upper()] for d in departments if default_map.get(d.upper())), default).website_url
